@@ -463,7 +463,7 @@ $VERSION = 1.01;
 
 sub new {
   my $self = shift;
-  my $self = bless {},$self unless ref $self;
+  $self = bless {},$self unless ref $self;
   $self->_open(@_);
   return $self;
 }
@@ -488,10 +488,9 @@ sub read_record {
   my $stone = new Stone;
   local $/ = "\n"; # normalize input stream
 
-  return unless my $line = <$fh>;
+  return unless defined(my $line = <$fh>);
   croak "Doesn't look like a BLAST stream to me - top line = '$_'" unless $line=~/BLAST/;
   return unless my ($program,$version,$date) = $line=~ /^(\S+) (\S+) \[([^\]]+)\]/;
-  my $stone = new Stone;
 
   $stone->insert ( Blast_version      => $version,
 		   Blast_program      => lc $program,
